@@ -1,7 +1,7 @@
 package Carton;
 use strict;
 use 5.008_005;
-use version; our $VERSION = version->declare("v0.9.54");
+use version; our $VERSION = version->declare("v0.9.55");
 
 1;
 __END__
@@ -23,7 +23,7 @@ Carton - Perl module dependency manager (aka Bundler for Perl)
 
   # Other developer's machine, or on a deployment box
   > carton install
-  > carton exec -Ilib -- starman -p 8080 myapp.psgi
+  > carton exec starman -p 8080 myapp.psgi
 
 =head1 WARNING
 
@@ -97,13 +97,13 @@ available on CPAN, such as internal distribution aka DarkPAN.
 
   > carton bundle
 
-will bundle these tarballs into I<local/cache> directory, and
+will bundle these tarballs into I<vendor/cache> directory, and
 
   > carton install --cached
 
-will install modules using this local cache. This way you can avoid a
-dependency on CPAN meta DB and search.cpan.org at a deploy time, or
-you can have dependencies onto private CPAN modules aka DarkPAN.
+will install modules using this local cache. This way you can avoid
+querying for a database like CPAN Meta DB or CPAN mirrors upon
+deployment time.
 
 =head1 COMMUNITY
 
